pyautomail
==========

.. automodule:: pyautomail
   :members:
   :undoc-members:
   :show-inheritance:


.. toctree::
   :maxdepth: 2

   pyautomail.config
   pyautomail.storage



pyautomail.cli
--------------


.. automodule:: pyautomail.cli
   :members:
   :undoc-members:
   :show-inheritance:

pyautomail.emailsender
----------------------


.. automodule:: pyautomail.emailsender
   :members:
   :undoc-members:
   :show-inheritance:

pyautomail.manager
------------------


.. automodule:: pyautomail.manager
   :members:
   :undoc-members:
   :show-inheritance:

pyautomail.utils
----------------


.. automodule:: pyautomail.utils
   :members:
   :undoc-members:
   :show-inheritance:
